@@ -5,13 +5,12 @@ import time
 import unittest
 from multiprocessing import connection
 
-from six.moves import queue
-
 from nose2 import session
+import six
 from nose2.plugins import buffer
 from nose2.plugins.loader import discovery, testcases
 from nose2.plugins.mp import MultiProcess, procserver
-from nose2.tests._common import Conn, FunctionalTestCase, support_file
+from nose2.tests._common import Conn, FunctionalTestCase, _method_name, support_file
 
 
 class TestMpPlugin(FunctionalTestCase):
@@ -263,7 +262,7 @@ class MPPluginTestRuns(FunctionalTestCase):
             "--plugin=nose2.plugins.mp",
             "-N=2",
         )
-        ret_vals = queue.Queue()
+        ret_vals = six.moves.queue.Queue()
 
         def save_return():
             """
@@ -281,11 +280,11 @@ class MPPluginTestRuns(FunctionalTestCase):
         thread = threading.Thread(target=save_return)
         thread.start()
 
-        # 1 minute should be more than sufficent for this
+        # 1 minute should be more than sufficient for this
         # little test case.
         try:
             exc = ret_vals.get(True, 60)
-        except queue.Empty:
+        except six.moves.queue.Empty:
             exc = "MP Test timed out"
             proc.kill()
         self.assertIsNone(exc, str(exc))
@@ -404,10 +403,16 @@ class MPClassFixturesSupport(FunctionalTestCase):
         )
         # report should show correct names for all tests
         self.assertTestRunOutputMatches(
-            proc, stderr=r"test_1 \(test_cf_testcase.Test\) ... ok"
+            proc,
+            stderr=r"test_1 \(test_cf_testcase.Test"
+            + _method_name("test_1")
+            + r"\) ... ok",
         )
         self.assertTestRunOutputMatches(
-            proc, stderr=r"test_2 \(test_cf_testcase.Test\) ... ok"
+            proc,
+            stderr=r"test_2 \(test_cf_testcase.Test"
+            + _method_name("test_2")
+            + r"\) ... ok",
         )
         self.assertTestRunOutputMatches(proc, stderr="Ran 2 tests")
         self.assertEqual(proc.poll(), 0)
@@ -484,10 +489,16 @@ class MPModuleFixturesSupport(FunctionalTestCase):
         )
         # report should show correct names for all tests
         self.assertTestRunOutputMatches(
-            proc, stderr=r"test_1 \(test_mf_testcase.Test\) ... ok"
+            proc,
+            stderr=r"test_1 \(test_mf_testcase.Test"
+            + _method_name("test_1")
+            + r"\) ... ok",
         )
         self.assertTestRunOutputMatches(
-            proc, stderr=r"test_2 \(test_mf_testcase.Test\) ... ok"
+            proc,
+            stderr=r"test_2 \(test_mf_testcase.Test"
+            + _method_name("test_2")
+            + r"\) ... ok",
         )
         self.assertTestRunOutputMatches(proc, stderr="Ran 2 tests")
         self.assertEqual(proc.poll(), 0)
